# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

import types

__config__ = pulumi.Config('materialize')


class _ExportableConfig(types.ModuleType):
    @property
    def application_name_suffix(self) -> Optional[str]:
        """
        A suffix to include in the `application_name` session parameter when connecting to Materialize.
        """
        return __config__.get('applicationNameSuffix')

    @property
    def database(self) -> Optional[str]:
        """
        The Materialize database. Can also come from the `MZ_DATABASE` environment variable. Defaults to `materialize`.
        """
        return __config__.get('database')

    @property
    def host(self) -> Optional[str]:
        """
        Materialize host. Can also come from the `MZ_HOST` environment variable.
        """
        return __config__.get('host')

    @property
    def password(self) -> Optional[str]:
        """
        Materialize host. Can also come from the `MZ_PASSWORD` environment variable.
        """
        return __config__.get('password')

    @property
    def port(self) -> Optional[int]:
        """
        The Materialize port number to connect to at the server host. Can also come from the `MZ_PORT` environment variable.
        Defaults to 6875.
        """
        return __config__.get_int('port')

    @property
    def sslmode(self) -> Optional[str]:
        """
        For testing purposes, the SSL mode to use.
        """
        return __config__.get('sslmode')

    @property
    def user(self) -> Optional[str]:
        """
        Materialize user. Can also come from the `MZ_USER` environment variable.
        """
        return __config__.get('user')

